@@ -21,15 +21,17 @@ import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_rds._jsii
 import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_route53_targets._jsii
+import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
+import cdk_nag._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "serverless-container-constructs",
-    "0.1.1",
+    "0.1.2",
     __name__[0:-6],
-    "serverless-container-constructs@0.1.1.jsii.tgz",
+    "serverless-container-constructs@0.1.2.jsii.tgz",
 )
 
 __all__ = [
